==> zio-aws-acmpca_2.12-5.17.295.16-sources.jar: zio/aws/acmpca/model/CsrExtensions.scala <==
package zio.aws.acmpca.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CsrExtensions(
    keyUsage: Optional[zio.aws.acmpca.model.KeyUsage] = Optional.Absent,
    subjectInformationAccess: Optional[
      Iterable[zio.aws.acmpca.model.AccessDescription]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.acmpca.model.CsrExtensions = {
    import CsrExtensions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.acmpca.model.CsrExtensions
      .builder()
      .optionallyWith(keyUsage.map(value => value.buildAwsValue()))(_.keyUsage)
      .optionallyWith(
        subjectInformationAccess.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.subjectInformationAccess)
      .build()
  }
  def asReadOnly: zio.aws.acmpca.model.CsrExtensions.ReadOnly =
    zio.aws.acmpca.model.CsrExtensions.wrap(buildAwsValue())
}
object CsrExtensions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.acmpca.model.CsrExtensions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.acmpca.model.CsrExtensions =
      zio.aws.acmpca.model.CsrExtensions(
        keyUsage.map(value => value.asEditable),
        subjectInformationAccess.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def keyUsage: Optional[zio.aws.acmpca.model.KeyUsage.ReadOnly]
    def subjectInformationAccess
        : Optional[List[zio.aws.acmpca.model.AccessDescription.ReadOnly]]
    def getKeyUsage
        : ZIO[Any, AwsError, zio.aws.acmpca.model.KeyUsage.ReadOnly] =
      AwsError.unwrapOptionField("keyUsage", keyUsage)
    def getSubjectInformationAccess: ZIO[Any, AwsError, List[
      zio.aws.acmpca.model.AccessDescription.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "subjectInformationAccess",
      subjectInformationAccess
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.acmpca.model.CsrExtensions
  ) extends zio.aws.acmpca.model.CsrExtensions.ReadOnly {
    override val keyUsage: Optional[zio.aws.acmpca.model.KeyUsage.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.keyUsage())
        .map(value => zio.aws.acmpca.model.KeyUsage.wrap(value))
    override val subjectInformationAccess
        : Optional[List[zio.aws.acmpca.model.AccessDescription.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.subjectInformationAccess())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.acmpca.model.AccessDescription.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.acmpca.model.CsrExtensions
  ): zio.aws.acmpca.model.CsrExtensions.ReadOnly = new Wrapper(impl)
}

==> zio-aws-acmpca_2.13-5.17.104.8-sources.jar: zio/aws/acmpca/model/CsrExtensions.scala <==
package zio.aws.acmpca.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CsrExtensions(
    keyUsage: Option[zio.aws.acmpca.model.KeyUsage] = None,
    subjectInformationAccess: Option[
      Iterable[zio.aws.acmpca.model.AccessDescription]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.acmpca.model.CsrExtensions = {
    import CsrExtensions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.acmpca.model.CsrExtensions
      .builder()
      .optionallyWith(keyUsage.map(value => value.buildAwsValue()))(_.keyUsage)
      .optionallyWith(
        subjectInformationAccess.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.subjectInformationAccess)
      .build()
  }
  def asReadOnly: zio.aws.acmpca.model.CsrExtensions.ReadOnly =
    zio.aws.acmpca.model.CsrExtensions.wrap(buildAwsValue())
}
object CsrExtensions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.acmpca.model.CsrExtensions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.acmpca.model.CsrExtensions =
      zio.aws.acmpca.model.CsrExtensions(
        keyUsage.map(value => value.asEditable),
        subjectInformationAccess.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def keyUsage: Option[zio.aws.acmpca.model.KeyUsage.ReadOnly]
    def subjectInformationAccess
        : Option[List[zio.aws.acmpca.model.AccessDescription.ReadOnly]]
    def getKeyUsage
        : ZIO[Any, AwsError, zio.aws.acmpca.model.KeyUsage.ReadOnly] =
      AwsError.unwrapOptionField("keyUsage", keyUsage)
    def getSubjectInformationAccess: ZIO[Any, AwsError, List[
      zio.aws.acmpca.model.AccessDescription.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "subjectInformationAccess",
      subjectInformationAccess
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.acmpca.model.CsrExtensions
  ) extends zio.aws.acmpca.model.CsrExtensions.ReadOnly {
    override val keyUsage: Option[zio.aws.acmpca.model.KeyUsage.ReadOnly] =
      scala
        .Option(impl.keyUsage())
        .map(value => zio.aws.acmpca.model.KeyUsage.wrap(value))
    override val subjectInformationAccess
        : Option[List[zio.aws.acmpca.model.AccessDescription.ReadOnly]] = scala
      .Option(impl.subjectInformationAccess())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.acmpca.model.AccessDescription.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.acmpca.model.CsrExtensions
  ): zio.aws.acmpca.model.CsrExtensions.ReadOnly = new Wrapper(impl)
}
